@@ -47,6 +47,20 @@ fn memory_catalog_dereg_nonempty_schema() {
     assert!(cat.deregister_schema("foo", true).unwrap().is_some());
 }
 
+#[test]
+fn memory_catalog_dereg_nonempty_schema_with_table_removal() {
+    let cat = Arc::new(MemoryCatalogProvider::new()) as Arc<dyn CatalogProvider>;
+
+    let schema = Arc::new(MemorySchemaProvider::new()) as Arc<dyn SchemaProvider>;
+    let test_table =
+        Arc::new(EmptyTable::new(Arc::new(Schema::empty()))) as Arc<dyn TableProvider>;
+    schema.register_table("t".into(), test_table).unwrap();
+
+    cat.register_schema("foo", schema.clone()).unwrap();
+    schema.deregister_table("t").unwrap();
+    assert!(cat.deregister_schema("foo", false).unwrap().is_some());
+}
+
 #[test]
 fn memory_catalog_dereg_empty_schema() {
     let cat = Arc::new(MemoryCatalogProvider::new()) as Arc<dyn CatalogProvider>;
@@ -109,7 +123,7 @@ async fn test_mem_provider() {
     assert!(provider.table_exist(table_name));
     let other_table = EmptyTable::new(Arc::new(Schema::empty()));
     let result = provider.register_table(table_name.to_string(), Arc::new(other_table));
-    assert!(result.is_err());
+    assert!(result.is_err(), "The table test_table_exist already exists");
 }
 
 #[tokio::test]
