@@ -22,7 +22,7 @@ use crate::expr::{
     GroupingSet, InList, InSubquery, Like, Placeholder, ScalarFunction, TryCast, Unnest,
     WindowFunction, WindowFunctionParams,
 };
-use crate::{Expr, ExprFunctionExt};
+use crate::Expr;
 
 use datafusion_common::tree_node::{
     Transformed, TreeNode, TreeNodeContainer, TreeNodeRecursion, TreeNodeRefContainer,
@@ -97,9 +97,10 @@ impl TreeNode for Expr {
                     args,
                     partition_by,
                     order_by,
+                    filter,
                     ..
                 } = &window_fun.as_ref().params;
-                (args, partition_by, order_by).apply_ref_elements(f)
+                (args, partition_by, order_by, filter).apply_ref_elements(f)
             }
 
             Expr::InList(InList { expr, list, .. }) => {
@@ -241,20 +242,30 @@ impl TreeNode for Expr {
                             partition_by,
                             order_by,
                             window_frame,
+                            filter,
                             null_treatment,
+                            distinct,
                         },
                 } = *window_fun;
-                (args, partition_by, order_by).map_elements(f)?.update_data(
-                    |(new_args, new_partition_by, new_order_by)| {
-                        Expr::from(WindowFunction::new(fun, new_args))
-                            .partition_by(new_partition_by)
-                            .order_by(new_order_by)
-                            .window_frame(window_frame)
-                            .null_treatment(null_treatment)
-                            .build()
-                            .unwrap()
-                    },
-                )
+
+                (args, partition_by, order_by, filter)
+                    .map_elements(f)?
+                    .map_data(
+                        |(new_args, new_partition_by, new_order_by, new_filter)| {
+                            Ok(Expr::from(WindowFunction {
+                                fun,
+                                params: WindowFunctionParams {
+                                    args: new_args,
+                                    partition_by: new_partition_by,
+                                    order_by: new_order_by,
+                                    window_frame,
+                                    filter: new_filter,
+                                    null_treatment,
+                                    distinct,
+                                },
+                            }))
+                        },
+                    )?
             }
             Expr::AggregateFunction(AggregateFunction {
                 func,
