@@ -23,7 +23,7 @@ use datafusion_expr::{
     expr_rewriter::NamePreserver,
     planner::{ExprPlanner, PlannerResult, RawWindowExpr},
     utils::COUNT_STAR_EXPANSION,
-    Expr, ExprFunctionExt,
+    Expr,
 };
 
 #[derive(Debug)]
@@ -40,7 +40,9 @@ impl ExprPlanner for WindowFunctionPlanner {
             partition_by,
             order_by,
             window_frame,
+            filter,
             null_treatment,
+            distinct,
         } = raw_expr;
 
         let origin_expr = Expr::from(WindowFunction {
@@ -50,7 +52,9 @@ impl ExprPlanner for WindowFunctionPlanner {
                 partition_by,
                 order_by,
                 window_frame,
+                filter,
                 null_treatment,
+                distinct,
             },
         });
 
@@ -68,6 +72,8 @@ impl ExprPlanner for WindowFunctionPlanner {
                     order_by,
                     window_frame,
                     null_treatment,
+                    distinct,
+                    filter,
                 },
         } = *window_fun;
         let raw_expr = RawWindowExpr {
@@ -76,7 +82,9 @@ impl ExprPlanner for WindowFunctionPlanner {
             partition_by,
             order_by,
             window_frame,
+            filter,
             null_treatment,
+            distinct,
         };
 
         // TODO: remove the next line after `Expr::Wildcard` is removed
@@ -92,19 +100,23 @@ impl ExprPlanner for WindowFunctionPlanner {
                 partition_by,
                 order_by,
                 window_frame,
+                filter,
                 null_treatment,
+                distinct,
             } = raw_expr;
 
-            let new_expr = Expr::from(WindowFunction::new(
-                func_def,
-                vec![Expr::Literal(COUNT_STAR_EXPANSION, None)],
-            ))
-            .partition_by(partition_by)
-            .order_by(order_by)
-            .window_frame(window_frame)
-            .null_treatment(null_treatment)
-            .build()?;
-
+            let new_expr = Expr::from(WindowFunction {
+                fun: func_def,
+                params: WindowFunctionParams {
+                    args: vec![Expr::Literal(COUNT_STAR_EXPANSION, None)],
+                    partition_by,
+                    order_by,
+                    window_frame,
+                    filter,
+                    null_treatment,
+                    distinct,
+                },
+            });
             let new_expr = saved_name.restore(new_expr);
 
             return Ok(PlannerResult::Planned(new_expr));
