@@ -36,7 +36,7 @@ use datafusion_functions_window_common::partition::PartitionEvaluatorArgs;
 use field::WindowUDFFieldArgs;
 use std::any::Any;
 use std::fmt::Debug;
-use std::hash::{DefaultHasher, Hash, Hasher};
+use std::hash::Hash;
 use std::iter;
 use std::ops::Range;
 use std::sync::{Arc, LazyLock};
@@ -63,7 +63,7 @@ define_udwf_and_expr!(
 );
 
 /// Rank calculates the rank in the window function with order by
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq, Hash)]
 pub struct Rank {
     name: String,
     signature: Signature,
@@ -111,15 +111,14 @@ static RANK_DOCUMENTATION: LazyLock<Documentation> = LazyLock::new(|| {
             skips ranks for identical values.",
 
         "rank()")
-        .with_sql_example(r#"```sql
-    --Example usage of the rank window function:
-    SELECT department,
-           salary,
-           rank() OVER (PARTITION BY department ORDER BY salary DESC) AS rank
-    FROM employees;
-```
-
+        .with_sql_example(r#"
 ```sql
+-- Example usage of the rank window function:
+SELECT department,
+    salary,
+    rank() OVER (PARTITION BY department ORDER BY salary DESC) AS rank
+FROM employees;
+
 +-------------+--------+------+
 | department  | salary | rank |
 +-------------+--------+------+
@@ -130,7 +129,8 @@ static RANK_DOCUMENTATION: LazyLock<Documentation> = LazyLock::new(|| {
 | Engineering | 90000  | 1    |
 | Engineering | 80000  | 2    |
 +-------------+--------+------+
-```"#)
+```
+"#)
         .build()
 });
 
@@ -142,15 +142,14 @@ static DENSE_RANK_DOCUMENTATION: LazyLock<Documentation> = LazyLock::new(|| {
     Documentation::builder(DOC_SECTION_RANKING, "Returns the rank of the current row without gaps. This function ranks \
             rows in a dense manner, meaning consecutive ranks are assigned even for identical \
             values.", "dense_rank()")
-        .with_sql_example(r#"```sql
-    --Example usage of the dense_rank window function:
-    SELECT department,
-           salary,
-           dense_rank() OVER (PARTITION BY department ORDER BY salary DESC) AS dense_rank
-    FROM employees;
-```
-
+        .with_sql_example(r#"
 ```sql
+-- Example usage of the dense_rank window function:
+SELECT department,
+    salary,
+    dense_rank() OVER (PARTITION BY department ORDER BY salary DESC) AS dense_rank
+FROM employees;
+
 +-------------+--------+------------+
 | department  | salary | dense_rank |
 +-------------+--------+------------+
@@ -173,14 +172,12 @@ static PERCENT_RANK_DOCUMENTATION: LazyLock<Documentation> = LazyLock::new(|| {
     Documentation::builder(DOC_SECTION_RANKING, "Returns the percentage rank of the current row within its partition. \
             The value ranges from 0 to 1 and is computed as `(rank - 1) / (total_rows - 1)`.", "percent_rank()")
         .with_sql_example(r#"```sql
-    --Example usage of the percent_rank window function:
-    SELECT employee_id,
-           salary,
-           percent_rank() OVER (ORDER BY salary) AS percent_rank
-    FROM employees;
-```
+    -- Example usage of the percent_rank window function:
+SELECT employee_id,
+    salary,
+    percent_rank() OVER (ORDER BY salary) AS percent_rank
+FROM employees;
 
-```sql
 +-------------+--------+---------------+
 | employee_id | salary | percent_rank  |
 +-------------+--------+---------------+
@@ -243,34 +240,6 @@ impl WindowUDFImpl for Rank {
             RankType::Percent => Some(get_percent_rank_doc()),
         }
     }
-
-    fn equals(&self, other: &dyn WindowUDFImpl) -> bool {
-        let Some(other) = other.as_any().downcast_ref::<Self>() else {
-            return false;
-        };
-        let Self {
-            name,
-            signature,
-            rank_type,
-        } = self;
-        name == &other.name
-            && signature == &other.signature
-            && rank_type == &other.rank_type
-    }
-
-    fn hash_value(&self) -> u64 {
-        let Self {
-            name,
-            signature,
-            rank_type,
-        } = self;
-        let mut hasher = DefaultHasher::new();
-        std::any::type_name::<Self>().hash(&mut hasher);
-        name.hash(&mut hasher);
-        signature.hash(&mut hasher);
-        rank_type.hash(&mut hasher);
-        hasher.finish()
-    }
 }
 
 /// State for the RANK(rank) built-in window function.
