@@ -284,9 +284,7 @@ fn propagate_empty_relation() {
 
     assert_snapshot!(
     format!("{plan}"),
-    @r#"
-        EmptyRelation
-        "#
+    @"EmptyRelation: rows=0"
     );
 }
 
@@ -526,7 +524,7 @@ fn test_sql(sql: &str) -> Result<LogicalPlan> {
     let analyzer = Analyzer::new();
     let optimizer = Optimizer::new();
     // analyze and optimize the logical plan
-    let plan = analyzer.execute_and_check(plan, config.options(), |_, _| {})?;
+    let plan = analyzer.execute_and_check(plan, &config.options(), |_, _| {})?;
     optimizer.optimize(plan, &config, observe)
 }
 
