@@ -255,10 +255,11 @@ impl EquivalenceProperties {
     pub fn constants(&self) -> Vec<ConstExpr> {
         self.eq_group
             .iter()
-            .filter_map(|c| {
-                c.constant.as_ref().and_then(|across| {
-                    c.canonical_expr()
-                        .map(|expr| ConstExpr::new(Arc::clone(expr), across.clone()))
+            .flat_map(|c| {
+                c.iter().filter_map(|expr| {
+                    c.constant
+                        .as_ref()
+                        .map(|across| ConstExpr::new(Arc::clone(expr), across.clone()))
                 })
             })
             .collect()
@@ -315,7 +316,7 @@ impl EquivalenceProperties {
             self.oeq_class.extend(orderings);
             // Normalize given orderings to update the cache:
             self.oeq_cache.normal_cls.extend(normal_orderings);
-            // TODO: If no ordering is found to be redunant during extension, we
+            // TODO: If no ordering is found to be redundant during extension, we
             //       can use a shortcut algorithm to update the leading map.
             self.oeq_cache.update_map();
         }
@@ -326,6 +327,22 @@ impl EquivalenceProperties {
         self.add_orderings(std::iter::once(ordering));
     }
 
+    fn update_oeq_cache(&mut self) -> Result<()> {
+        // Renormalize orderings if the equivalence group changes:
+        let normal_cls = mem::take(&mut self.oeq_cache.normal_cls);
+        let normal_orderings = normal_cls
+            .into_iter()
+            .map(|o| self.eq_group.normalize_sort_exprs(o));
+        self.oeq_cache.normal_cls = OrderingEquivalenceClass::new(normal_orderings);
+        self.oeq_cache.update_map();
+        // Discover any new orderings based on the new equivalence classes:
+        let leading_exprs: Vec<_> = self.oeq_cache.leading_map.keys().cloned().collect();
+        for expr in leading_exprs {
+            self.discover_new_orderings(expr)?;
+        }
+        Ok(())
+    }
+
     /// Incorporates the given equivalence group to into the existing
     /// equivalence group within.
     pub fn add_equivalence_group(
@@ -334,19 +351,7 @@ impl EquivalenceProperties {
     ) -> Result<()> {
         if !other_eq_group.is_empty() {
             self.eq_group.extend(other_eq_group);
-            // Renormalize orderings if the equivalence group changes:
-            let normal_cls = mem::take(&mut self.oeq_cache.normal_cls);
-            let normal_orderings = normal_cls
-                .into_iter()
-                .map(|o| self.eq_group.normalize_sort_exprs(o));
-            self.oeq_cache.normal_cls = OrderingEquivalenceClass::new(normal_orderings);
-            self.oeq_cache.update_map();
-            // Discover any new orderings based on the new equivalence classes:
-            let leading_exprs: Vec<_> =
-                self.oeq_cache.leading_map.keys().cloned().collect();
-            for expr in leading_exprs {
-                self.discover_new_orderings(expr)?;
-            }
+            self.update_oeq_cache()?;
         }
         Ok(())
     }
@@ -373,16 +378,9 @@ impl EquivalenceProperties {
     ) -> Result<()> {
         // Add equal expressions to the state:
         if self.eq_group.add_equal_conditions(Arc::clone(&left), right) {
-            // Renormalize orderings if the equivalence group changes:
-            let normal_cls = mem::take(&mut self.oeq_cache.normal_cls);
-            let normal_orderings = normal_cls
-                .into_iter()
-                .map(|o| self.eq_group.normalize_sort_exprs(o));
-            self.oeq_cache.normal_cls = OrderingEquivalenceClass::new(normal_orderings);
-            self.oeq_cache.update_map();
-            // Discover any new orderings:
-            self.discover_new_orderings(left)?;
+            self.update_oeq_cache()?;
         }
+        self.update_oeq_cache()?;
         Ok(())
     }
 
